package examples.hibernate.domain;

import javax.persistence.*;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

@Entity
public class Passenger {
    /** 
     * Unique identifier.
     */
    @SuppressWarnings("unused")
    @Id @GeneratedValue(strategy=GenerationType.AUTO)
    private Long id;

    /**
     * Object version number.  
     * Necessary for the optimistic policy for concurrency control
     */
    @SuppressWarnings("unused")
    @Version
    private Long objVersion;    

    private String identifier;
    private String name;
    
    @ManyToMany(mappedBy="passengers")
    private Set<Airplane> airplanes;       // many-to-many bidirectional association
    
    protected Passenger() { }
    
    public Passenger(String name, String identifier) {
	airplanes = new HashSet<Airplane>();
	setName(name);
	setIdentifier(identifier);	
    }
    
    public String getIdentifier() {
	return identifier;
    }
    
    public void setIdentifier(String identifier) {
	this.identifier = identifier;
    }
    
    public String getName() {
	return name;
    }

    public void setName(String name) {
	this.name = name;
    }

    public Set<Airplane> getAirplanes() {
	return Collections.unmodifiableSet(airplanes);
    }
    
    protected void addAirplane(Airplane airplane) {
	this.airplanes.add(airplane);
    }

    protected void removeAirplane(Airplane airplane) {
	this.airplanes.remove(airplane);
    }
    
    public String toString() {
	StringBuilder sb = new StringBuilder("\t\tPassenger: ")
		.append(name)
		.append("\n\t\tID number: ")
		.append(identifier);
	return sb.toString();
    }

}
